pitchtools.calculate_harmonic_diatonic_interval_class
=====================================================

.. autofunction:: abjad.tools.pitchtools.calculate_harmonic_diatonic_interval_class.calculate_harmonic_diatonic_interval_class
   :noindex:
